windows-1256

أعلنت كتائب الشهيد عز الدين القسام الذراع العسكري لحركة /حماس/ عن قتل ثمانية من جنود الاحتلال الإسرائيلي مساء اليوم الجمعة في احد المنازل ببلدة بيت لاهيا شمال قطاع غزة . وقالت الكتائب في بيان تبنت فيه الهجوم " انه وفي عملية خاطفة ونوعية، تمكنت كتائب الشهيد عز الدين القسام في الساعة 16:20 من اقتحام منزل يحتله الجنود الإسرائيليين في حي السلاطين في بيت لاهيا شمال غرب قطاع غزة " . واضاف البيان " أن قوة خاصة من كتائب القسام اقتحمت المنزل أثناء تواجد عدد من الجنود وقد أجهز المجاهدون على القوة بشكل كامل، والتي ...